Class: Blockchain0xX402::Server::PricingEntry
- Inherits:
-
Struct
- Object
- Struct
- Blockchain0xX402::Server::PricingEntry
- Defined in:
- lib/blockchain0x_x402/server.rb
Instance Attribute Summary collapse
-
#amount_usdc ⇒ Object
Returns the value of attribute amount_usdc.
-
#network ⇒ Object
Returns the value of attribute network.
-
#pay_to_address ⇒ Object
Returns the value of attribute pay_to_address.
-
#payment_request_id ⇒ Object
Returns the value of attribute payment_request_id.
Instance Method Summary collapse
-
#initialize(amount_usdc:, pay_to_address:, payment_request_id:, network: nil) ⇒ PricingEntry
constructor
Optional ‘network` defaults to nil so the middleware can fall back to the global DefaultNetwork.
Constructor Details
#initialize(amount_usdc:, pay_to_address:, payment_request_id:, network: nil) ⇒ PricingEntry
Optional ‘network` defaults to nil so the middleware can fall back to the global DefaultNetwork. Struct’s keyword_init already nils unspecified fields; this initialiser only exists to enforce the three required ones.
55 56 57 |
# File 'lib/blockchain0x_x402/server.rb', line 55 def initialize(amount_usdc:, pay_to_address:, payment_request_id:, network: nil) super end |
Instance Attribute Details
#amount_usdc ⇒ Object
Returns the value of attribute amount_usdc
44 45 46 |
# File 'lib/blockchain0x_x402/server.rb', line 44 def amount_usdc @amount_usdc end |
#network ⇒ Object
Returns the value of attribute network
44 45 46 |
# File 'lib/blockchain0x_x402/server.rb', line 44 def network @network end |
#pay_to_address ⇒ Object
Returns the value of attribute pay_to_address
44 45 46 |
# File 'lib/blockchain0x_x402/server.rb', line 44 def pay_to_address @pay_to_address end |
#payment_request_id ⇒ Object
Returns the value of attribute payment_request_id
44 45 46 |
# File 'lib/blockchain0x_x402/server.rb', line 44 def payment_request_id @payment_request_id end |